Class: ElasticEmail::CampaignOptions
- Inherits:
-
Object
- Object
- ElasticEmail::CampaignOptions
- Defined in:
- lib/ElasticEmail/models/campaign_options.rb
Overview
Different send options for a Campaign
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#delivery_optimization ⇒ Object
Returns the value of attribute delivery_optimization.
-
#schedule_for ⇒ Object
Date when this Campaign is scheduled to be sent on.
-
#send_at_local_time ⇒ Object
Send email at local time of contact.
-
#split_options ⇒ Object
Returns the value of attribute split_options.
-
#track_clicks ⇒ Object
Should the clicks be tracked? If no value has been provided, Account's default setting will be used.
-
#track_opens ⇒ Object
Should the opens be tracked? If no value has been provided, Account's default setting will be used.
-
#trigger_count ⇒ Object
How many times send the campaign.
-
#trigger_frequency ⇒ Object
How often (in minutes) to send the campaign.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CampaignOptions
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CampaignOptions
Initializes the object
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/ElasticEmail/models/campaign_options.rb', line 108 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `ElasticEmail::CampaignOptions` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `ElasticEmail::CampaignOptions`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'delivery_optimization') self.delivery_optimization = attributes[:'delivery_optimization'] else self.delivery_optimization = 'None' end if attributes.key?(:'track_opens') self.track_opens = attributes[:'track_opens'] end if attributes.key?(:'track_clicks') self.track_clicks = attributes[:'track_clicks'] end if attributes.key?(:'schedule_for') self.schedule_for = attributes[:'schedule_for'] end if attributes.key?(:'trigger_frequency') self.trigger_frequency = attributes[:'trigger_frequency'] end if attributes.key?(:'trigger_count') self.trigger_count = attributes[:'trigger_count'] end if attributes.key?(:'split_options') self. = attributes[:'split_options'] end if attributes.key?(:'send_at_local_time') self.send_at_local_time = attributes[:'send_at_local_time'] end end |
Instance Attribute Details
#delivery_optimization ⇒ Object
Returns the value of attribute delivery_optimization.
19 20 21 |
# File 'lib/ElasticEmail/models/campaign_options.rb', line 19 def delivery_optimization @delivery_optimization end |
#schedule_for ⇒ Object
Date when this Campaign is scheduled to be sent on
28 29 30 |
# File 'lib/ElasticEmail/models/campaign_options.rb', line 28 def schedule_for @schedule_for end |
#send_at_local_time ⇒ Object
Send email at local time of contact.
39 40 41 |
# File 'lib/ElasticEmail/models/campaign_options.rb', line 39 def send_at_local_time @send_at_local_time end |
#split_options ⇒ Object
Returns the value of attribute split_options.
36 37 38 |
# File 'lib/ElasticEmail/models/campaign_options.rb', line 36 def @split_options end |
#track_clicks ⇒ Object
Should the clicks be tracked? If no value has been provided, Account's default setting will be used.
25 26 27 |
# File 'lib/ElasticEmail/models/campaign_options.rb', line 25 def track_clicks @track_clicks end |
#track_opens ⇒ Object
Should the opens be tracked? If no value has been provided, Account's default setting will be used.
22 23 24 |
# File 'lib/ElasticEmail/models/campaign_options.rb', line 22 def track_opens @track_opens end |
#trigger_count ⇒ Object
How many times send the campaign
34 35 36 |
# File 'lib/ElasticEmail/models/campaign_options.rb', line 34 def trigger_count @trigger_count end |
#trigger_frequency ⇒ Object
How often (in minutes) to send the campaign
31 32 33 |
# File 'lib/ElasticEmail/models/campaign_options.rb', line 31 def trigger_frequency @trigger_frequency end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/ElasticEmail/models/campaign_options.rb', line 225 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = ElasticEmail.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
78 79 80 |
# File 'lib/ElasticEmail/models/campaign_options.rb', line 78 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/ElasticEmail/models/campaign_options.rb', line 64 def self.attribute_map { :'delivery_optimization' => :'DeliveryOptimization', :'track_opens' => :'TrackOpens', :'track_clicks' => :'TrackClicks', :'schedule_for' => :'ScheduleFor', :'trigger_frequency' => :'TriggerFrequency', :'trigger_count' => :'TriggerCount', :'split_options' => :'SplitOptions', :'send_at_local_time' => :'SendAtLocalTime' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/ElasticEmail/models/campaign_options.rb', line 201 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
97 98 99 100 101 102 103 104 |
# File 'lib/ElasticEmail/models/campaign_options.rb', line 97 def self.openapi_nullable Set.new([ :'track_opens', :'track_clicks', :'schedule_for', :'send_at_local_time' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/ElasticEmail/models/campaign_options.rb', line 83 def self.openapi_types { :'delivery_optimization' => :'DeliveryOptimizationType', :'track_opens' => :'Boolean', :'track_clicks' => :'Boolean', :'schedule_for' => :'Time', :'trigger_frequency' => :'Float', :'trigger_count' => :'Integer', :'split_options' => :'SplitOptions', :'send_at_local_time' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/ElasticEmail/models/campaign_options.rb', line 173 def ==(o) return true if self.equal?(o) self.class == o.class && delivery_optimization == o.delivery_optimization && track_opens == o.track_opens && track_clicks == o.track_clicks && schedule_for == o.schedule_for && trigger_frequency == o.trigger_frequency && trigger_count == o.trigger_count && == o. && send_at_local_time == o.send_at_local_time end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/ElasticEmail/models/campaign_options.rb', line 296 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
188 189 190 |
# File 'lib/ElasticEmail/models/campaign_options.rb', line 188 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
194 195 196 |
# File 'lib/ElasticEmail/models/campaign_options.rb', line 194 def hash [delivery_optimization, track_opens, track_clicks, schedule_for, trigger_frequency, trigger_count, , send_at_local_time].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
158 159 160 161 162 |
# File 'lib/ElasticEmail/models/campaign_options.rb', line 158 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
272 273 274 |
# File 'lib/ElasticEmail/models/campaign_options.rb', line 272 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/ElasticEmail/models/campaign_options.rb', line 278 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
266 267 268 |
# File 'lib/ElasticEmail/models/campaign_options.rb', line 266 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
166 167 168 169 |
# File 'lib/ElasticEmail/models/campaign_options.rb', line 166 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |