Class: ElasticEmail::CampaignsApi
- Inherits:
-
Object
- Object
- ElasticEmail::CampaignsApi
- Defined in:
- lib/ElasticEmail/api/campaigns_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#campaigns_automation_by_name_trigger_post(name, contact_email, opts = {}) ⇒ nil
Trigger Automation for Contact Manually trigger an Automation for a contact.
-
#campaigns_automation_by_name_trigger_post_with_http_info(name, contact_email, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Trigger Automation for Contact Manually trigger an Automation for a contact.
-
#campaigns_by_name_delete(name, opts = {}) ⇒ nil
Delete Campaign Delete the specific campaign.
-
#campaigns_by_name_delete_with_http_info(name, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete Campaign Delete the specific campaign.
-
#campaigns_by_name_get(name, opts = {}) ⇒ Campaign
Load Campaign Returns the specified campaign details.
-
#campaigns_by_name_get_with_http_info(name, opts = {}) ⇒ Array<(Campaign, Integer, Hash)>
Load Campaign Returns the specified campaign details.
-
#campaigns_by_name_pause_put(name, opts = {}) ⇒ nil
Pause Campaign Pauses the specific campaign, cancelling emails that are waiting to be sent.
-
#campaigns_by_name_pause_put_with_http_info(name, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Pause Campaign Pauses the specific campaign, cancelling emails that are waiting to be sent.
-
#campaigns_by_name_put(name, campaign, opts = {}) ⇒ Campaign
Update Campaign Updates a previously added campaign.
-
#campaigns_by_name_put_with_http_info(name, campaign, opts = {}) ⇒ Array<(Campaign, Integer, Hash)>
Update Campaign Updates a previously added campaign.
-
#campaigns_get(opts = {}) ⇒ Array<Campaign>
Load Campaigns Returns a list all of your campaigns.
-
#campaigns_get_with_http_info(opts = {}) ⇒ Array<(Array<Campaign>, Integer, Hash)>
Load Campaigns Returns a list all of your campaigns.
-
#campaigns_post(campaign, opts = {}) ⇒ Campaign
Add Campaign Add a campaign for processing.
-
#campaigns_post_with_http_info(campaign, opts = {}) ⇒ Array<(Campaign, Integer, Hash)>
Add Campaign Add a campaign for processing.
-
#initialize(api_client = ApiClient.default) ⇒ CampaignsApi
constructor
A new instance of CampaignsApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ CampaignsApi
Returns a new instance of CampaignsApi.
19 20 21 |
# File 'lib/ElasticEmail/api/campaigns_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/ElasticEmail/api/campaigns_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#campaigns_automation_by_name_trigger_post(name, contact_email, opts = {}) ⇒ nil
Trigger Automation for Contact Manually trigger an Automation for a contact. Required Access Level: ModifyAutomations
28 29 30 31 |
# File 'lib/ElasticEmail/api/campaigns_api.rb', line 28 def campaigns_automation_by_name_trigger_post(name, contact_email, opts = {}) campaigns_automation_by_name_trigger_post_with_http_info(name, contact_email, opts) nil end |
#campaigns_automation_by_name_trigger_post_with_http_info(name, contact_email, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Trigger Automation for Contact Manually trigger an Automation for a contact. Required Access Level: ModifyAutomations
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/ElasticEmail/api/campaigns_api.rb', line 39 def campaigns_automation_by_name_trigger_post_with_http_info(name, contact_email, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CampaignsApi.campaigns_automation_by_name_trigger_post ...' end # verify the required parameter 'name' is set if @api_client.config.client_side_validation && name.nil? fail ArgumentError, "Missing the required parameter 'name' when calling CampaignsApi.campaigns_automation_by_name_trigger_post" end # verify the required parameter 'contact_email' is set if @api_client.config.client_side_validation && contact_email.nil? fail ArgumentError, "Missing the required parameter 'contact_email' when calling CampaignsApi.campaigns_automation_by_name_trigger_post" end # resource path local_var_path = '/campaigns/automation/{name}/trigger'.sub('{' + 'name' + '}', CGI.escape(name.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'contactEmail'] = contact_email # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['apikey'] = opts.merge( :operation => :"CampaignsApi.campaigns_automation_by_name_trigger_post", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CampaignsApi#campaigns_automation_by_name_trigger_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#campaigns_by_name_delete(name, opts = {}) ⇒ nil
Delete Campaign Delete the specific campaign. This does not cancel in progress email, see Cancel In Progress. Required Access Level: ModifyCampaigns
95 96 97 98 |
# File 'lib/ElasticEmail/api/campaigns_api.rb', line 95 def campaigns_by_name_delete(name, opts = {}) campaigns_by_name_delete_with_http_info(name, opts) nil end |
#campaigns_by_name_delete_with_http_info(name, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete Campaign Delete the specific campaign. This does not cancel in progress email, see Cancel In Progress. Required Access Level: ModifyCampaigns
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/ElasticEmail/api/campaigns_api.rb', line 105 def campaigns_by_name_delete_with_http_info(name, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CampaignsApi.campaigns_by_name_delete ...' end # verify the required parameter 'name' is set if @api_client.config.client_side_validation && name.nil? fail ArgumentError, "Missing the required parameter 'name' when calling CampaignsApi.campaigns_by_name_delete" end # resource path local_var_path = '/campaigns/{name}'.sub('{' + 'name' + '}', CGI.escape(name.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['apikey'] = opts.merge( :operation => :"CampaignsApi.campaigns_by_name_delete", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CampaignsApi#campaigns_by_name_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#campaigns_by_name_get(name, opts = {}) ⇒ Campaign
Load Campaign Returns the specified campaign details. Required Access Level: ViewCampaigns
156 157 158 159 |
# File 'lib/ElasticEmail/api/campaigns_api.rb', line 156 def campaigns_by_name_get(name, opts = {}) data, _status_code, _headers = campaigns_by_name_get_with_http_info(name, opts) data end |
#campaigns_by_name_get_with_http_info(name, opts = {}) ⇒ Array<(Campaign, Integer, Hash)>
Load Campaign Returns the specified campaign details. Required Access Level: ViewCampaigns
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/ElasticEmail/api/campaigns_api.rb', line 166 def campaigns_by_name_get_with_http_info(name, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CampaignsApi.campaigns_by_name_get ...' end # verify the required parameter 'name' is set if @api_client.config.client_side_validation && name.nil? fail ArgumentError, "Missing the required parameter 'name' when calling CampaignsApi.campaigns_by_name_get" end # resource path local_var_path = '/campaigns/{name}'.sub('{' + 'name' + '}', CGI.escape(name.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Campaign' # auth_names auth_names = opts[:debug_auth_names] || ['apikey'] = opts.merge( :operation => :"CampaignsApi.campaigns_by_name_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CampaignsApi#campaigns_by_name_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#campaigns_by_name_pause_put(name, opts = {}) ⇒ nil
Pause Campaign Pauses the specific campaign, cancelling emails that are waiting to be sent. Required Access Level: ModifyCampaigns
219 220 221 222 |
# File 'lib/ElasticEmail/api/campaigns_api.rb', line 219 def campaigns_by_name_pause_put(name, opts = {}) campaigns_by_name_pause_put_with_http_info(name, opts) nil end |
#campaigns_by_name_pause_put_with_http_info(name, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Pause Campaign Pauses the specific campaign, cancelling emails that are waiting to be sent. Required Access Level: ModifyCampaigns
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/ElasticEmail/api/campaigns_api.rb', line 229 def campaigns_by_name_pause_put_with_http_info(name, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CampaignsApi.campaigns_by_name_pause_put ...' end # verify the required parameter 'name' is set if @api_client.config.client_side_validation && name.nil? fail ArgumentError, "Missing the required parameter 'name' when calling CampaignsApi.campaigns_by_name_pause_put" end # resource path local_var_path = '/campaigns/{name}/pause'.sub('{' + 'name' + '}', CGI.escape(name.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['apikey'] = opts.merge( :operation => :"CampaignsApi.campaigns_by_name_pause_put", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CampaignsApi#campaigns_by_name_pause_put\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#campaigns_by_name_put(name, campaign, opts = {}) ⇒ Campaign
Update Campaign Updates a previously added campaign. Only Active and Paused campaigns can be updated. Required Access Level: ModifyCampaigns
281 282 283 284 |
# File 'lib/ElasticEmail/api/campaigns_api.rb', line 281 def campaigns_by_name_put(name, campaign, opts = {}) data, _status_code, _headers = campaigns_by_name_put_with_http_info(name, campaign, opts) data end |
#campaigns_by_name_put_with_http_info(name, campaign, opts = {}) ⇒ Array<(Campaign, Integer, Hash)>
Update Campaign Updates a previously added campaign. Only Active and Paused campaigns can be updated. Required Access Level: ModifyCampaigns
292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 |
# File 'lib/ElasticEmail/api/campaigns_api.rb', line 292 def campaigns_by_name_put_with_http_info(name, campaign, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CampaignsApi.campaigns_by_name_put ...' end # verify the required parameter 'name' is set if @api_client.config.client_side_validation && name.nil? fail ArgumentError, "Missing the required parameter 'name' when calling CampaignsApi.campaigns_by_name_put" end # verify the required parameter 'campaign' is set if @api_client.config.client_side_validation && campaign.nil? fail ArgumentError, "Missing the required parameter 'campaign' when calling CampaignsApi.campaigns_by_name_put" end # resource path local_var_path = '/campaigns/{name}'.sub('{' + 'name' + '}', CGI.escape(name.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(campaign) # return_type return_type = opts[:debug_return_type] || 'Campaign' # auth_names auth_names = opts[:debug_auth_names] || ['apikey'] = opts.merge( :operation => :"CampaignsApi.campaigns_by_name_put", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CampaignsApi#campaigns_by_name_put\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#campaigns_get(opts = {}) ⇒ Array<Campaign>
Load Campaigns Returns a list all of your campaigns. Limited to 1000 results. Required Access Level: ViewCampaigns
356 357 358 359 |
# File 'lib/ElasticEmail/api/campaigns_api.rb', line 356 def campaigns_get(opts = {}) data, _status_code, _headers = campaigns_get_with_http_info(opts) data end |
#campaigns_get_with_http_info(opts = {}) ⇒ Array<(Array<Campaign>, Integer, Hash)>
Load Campaigns Returns a list all of your campaigns. Limited to 1000 results. Required Access Level: ViewCampaigns
368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 |
# File 'lib/ElasticEmail/api/campaigns_api.rb', line 368 def campaigns_get_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CampaignsApi.campaigns_get ...' end # resource path local_var_path = '/campaigns' # query parameters query_params = opts[:query_params] || {} query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<Campaign>' # auth_names auth_names = opts[:debug_auth_names] || ['apikey'] = opts.merge( :operation => :"CampaignsApi.campaigns_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CampaignsApi#campaigns_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#campaigns_post(campaign, opts = {}) ⇒ Campaign
Add Campaign Add a campaign for processing. Required Access Level: ModifyCampaigns
420 421 422 423 |
# File 'lib/ElasticEmail/api/campaigns_api.rb', line 420 def campaigns_post(campaign, opts = {}) data, _status_code, _headers = campaigns_post_with_http_info(campaign, opts) data end |
#campaigns_post_with_http_info(campaign, opts = {}) ⇒ Array<(Campaign, Integer, Hash)>
Add Campaign Add a campaign for processing. Required Access Level: ModifyCampaigns
430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 |
# File 'lib/ElasticEmail/api/campaigns_api.rb', line 430 def campaigns_post_with_http_info(campaign, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CampaignsApi.campaigns_post ...' end # verify the required parameter 'campaign' is set if @api_client.config.client_side_validation && campaign.nil? fail ArgumentError, "Missing the required parameter 'campaign' when calling CampaignsApi.campaigns_post" end # resource path local_var_path = '/campaigns' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(campaign) # return_type return_type = opts[:debug_return_type] || 'Campaign' # auth_names auth_names = opts[:debug_auth_names] || ['apikey'] = opts.merge( :operation => :"CampaignsApi.campaigns_post", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CampaignsApi#campaigns_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |