Class: ElasticEmail::EmailStatus

Inherits:
Object
  • Object
show all
Defined in:
lib/ElasticEmail/models/email_status.rb

Overview

Status information of the specified email

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ EmailStatus

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/ElasticEmail/models/email_status.rb', line 131

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ElasticEmail::EmailStatus` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ElasticEmail::EmailStatus`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'from')
    self.from = attributes[:'from']
  end

  if attributes.key?(:'to')
    self.to = attributes[:'to']
  end

  if attributes.key?(:'date')
    self.date = attributes[:'date']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = 'All'
  end

  if attributes.key?(:'status_name')
    self.status_name = attributes[:'status_name']
  end

  if attributes.key?(:'status_change_date')
    self.status_change_date = attributes[:'status_change_date']
  end

  if attributes.key?(:'date_sent')
    self.date_sent = attributes[:'date_sent']
  end

  if attributes.key?(:'date_opened')
    self.date_opened = attributes[:'date_opened']
  end

  if attributes.key?(:'date_clicked')
    self.date_clicked = attributes[:'date_clicked']
  end

  if attributes.key?(:'error_message')
    self.error_message = attributes[:'error_message']
  end

  if attributes.key?(:'transaction_id')
    self.transaction_id = attributes[:'transaction_id']
  end

  if attributes.key?(:'envelope_from')
    self.envelope_from = attributes[:'envelope_from']
  end

  if attributes.key?(:'error_category')
    self.error_category = attributes[:'error_category']
  else
    self.error_category = 'Unknown'
  end
end

Instance Attribute Details

#dateObject

Date the email was submitted.



26
27
28
# File 'lib/ElasticEmail/models/email_status.rb', line 26

def date
  @date
end

#date_clickedObject

Date when the email changed the status to 'clicked'



43
44
45
# File 'lib/ElasticEmail/models/email_status.rb', line 43

def date_clicked
  @date_clicked
end

#date_openedObject

Date when the email changed the status to 'opened'



40
41
42
# File 'lib/ElasticEmail/models/email_status.rb', line 40

def date_opened
  @date_opened
end

#date_sentObject

Date when the email was sent



37
38
39
# File 'lib/ElasticEmail/models/email_status.rb', line 37

def date_sent
  @date_sent
end

#envelope_fromObject

Envelope from address



52
53
54
# File 'lib/ElasticEmail/models/email_status.rb', line 52

def envelope_from
  @envelope_from
end

#error_categoryObject

Returns the value of attribute error_category.



54
55
56
# File 'lib/ElasticEmail/models/email_status.rb', line 54

def error_category
  @error_category
end

#error_messageObject

Detailed error or bounced message.



46
47
48
# File 'lib/ElasticEmail/models/email_status.rb', line 46

def error_message
  @error_message
end

#fromObject

Email address this email was sent from.



20
21
22
# File 'lib/ElasticEmail/models/email_status.rb', line 20

def from
  @from
end

#statusObject

Returns the value of attribute status.



28
29
30
# File 'lib/ElasticEmail/models/email_status.rb', line 28

def status
  @status
end

#status_change_dateObject

Date of last status change.



34
35
36
# File 'lib/ElasticEmail/models/email_status.rb', line 34

def status_change_date
  @status_change_date
end

#status_nameObject

Name of email's status



31
32
33
# File 'lib/ElasticEmail/models/email_status.rb', line 31

def status_name
  @status_name
end

#toObject

Email address this email was sent to.



23
24
25
# File 'lib/ElasticEmail/models/email_status.rb', line 23

def to
  @to
end

#transaction_idObject

ID number of transaction



49
50
51
# File 'lib/ElasticEmail/models/email_status.rb', line 49

def transaction_id
  @transaction_id
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/ElasticEmail/models/email_status.rb', line 275

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = ElasticEmail.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



98
99
100
# File 'lib/ElasticEmail/models/email_status.rb', line 98

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/ElasticEmail/models/email_status.rb', line 79

def self.attribute_map
  {
    :'from' => :'From',
    :'to' => :'To',
    :'date' => :'Date',
    :'status' => :'Status',
    :'status_name' => :'StatusName',
    :'status_change_date' => :'StatusChangeDate',
    :'date_sent' => :'DateSent',
    :'date_opened' => :'DateOpened',
    :'date_clicked' => :'DateClicked',
    :'error_message' => :'ErrorMessage',
    :'transaction_id' => :'TransactionID',
    :'envelope_from' => :'EnvelopeFrom',
    :'error_category' => :'ErrorCategory'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/ElasticEmail/models/email_status.rb', line 251

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



122
123
124
125
126
127
# File 'lib/ElasticEmail/models/email_status.rb', line 122

def self.openapi_nullable
  Set.new([
    :'date_opened',
    :'date_clicked',
  ])
end

.openapi_typesObject

Attribute type mapping.



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/ElasticEmail/models/email_status.rb', line 103

def self.openapi_types
  {
    :'from' => :'String',
    :'to' => :'String',
    :'date' => :'Time',
    :'status' => :'LogJobStatus',
    :'status_name' => :'String',
    :'status_change_date' => :'Time',
    :'date_sent' => :'Time',
    :'date_opened' => :'Time',
    :'date_clicked' => :'Time',
    :'error_message' => :'String',
    :'transaction_id' => :'String',
    :'envelope_from' => :'String',
    :'error_category' => :'MessageCategoryEnum'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/ElasticEmail/models/email_status.rb', line 218

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      from == o.from &&
      to == o.to &&
      date == o.date &&
      status == o.status &&
      status_name == o.status_name &&
      status_change_date == o.status_change_date &&
      date_sent == o.date_sent &&
      date_opened == o.date_opened &&
      date_clicked == o.date_clicked &&
      error_message == o.error_message &&
      transaction_id == o.transaction_id &&
      envelope_from == o.envelope_from &&
      error_category == o.error_category
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



346
347
348
349
350
351
352
353
354
355
356
357
358
# File 'lib/ElasticEmail/models/email_status.rb', line 346

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


238
239
240
# File 'lib/ElasticEmail/models/email_status.rb', line 238

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



244
245
246
# File 'lib/ElasticEmail/models/email_status.rb', line 244

def hash
  [from, to, date, status, status_name, status_change_date, date_sent, date_opened, date_clicked, error_message, transaction_id, envelope_from, error_category].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



203
204
205
206
207
# File 'lib/ElasticEmail/models/email_status.rb', line 203

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



322
323
324
# File 'lib/ElasticEmail/models/email_status.rb', line 322

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



328
329
330
331
332
333
334
335
336
337
338
339
340
# File 'lib/ElasticEmail/models/email_status.rb', line 328

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



316
317
318
# File 'lib/ElasticEmail/models/email_status.rb', line 316

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



211
212
213
214
# File 'lib/ElasticEmail/models/email_status.rb', line 211

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end